@@ -27,6 +27,10 @@ import javax.imageio.ImageIO;
 import javax.swing.JOptionPane;
 
 import org.apache.log4j.Logger;
+import org.gcube.portlets.user.gisviewer.client.commons.utils.MapServerRecognize;
+import org.gcube.portlets.user.gisviewer.client.commons.utils.MapServerRecognize.SERVERTYPE;
+
+import com.google.gwt.core.shared.GWT;
 
 
 /**
@@ -75,6 +79,7 @@ public class MapGeneratorUtils {
 			for (int i=0; i<layers.length; i++) {
 				int gsref = Integer.parseInt(gsrefs[i]);	
 				String geoserver = geoservers[gsref];
+				
 				logger.info("creating requesting for wms url: "+geoserver);
 				String layer = layers[i];
 				String style = styles[i];
@@ -83,8 +88,22 @@ public class MapGeneratorUtils {
 				
 				//ADDED BY FRANCESCO M. FOR Map Server parameters
 				String wmsStyleParam="";
-				if(style!=null && !style.isEmpty() && !style.equals("null")){
-					wmsStyleParam = "&STYLES="+style;
+//				if(style!=null && !style.isEmpty() && !style.equals("null")){
+//					wmsStyleParam = "&STYLES="+style;
+//				}
+				
+				//CASE MAP SERVER
+				SERVERTYPE mapserverType = MapServerRecognize.recongnize(geoserver);
+				logger.info("Recongnized SERVERTYPE: "+mapserverType);
+				
+				if(mapserverType!=null){
+					if(mapserverType.equals(SERVERTYPE.MAPSERVER)){
+						if(style!=null && !style.isEmpty() && !style.equals("null")){
+							wmsStyleParam = "&STYLES="+style;
+						}
+					}else {
+						wmsStyleParam = "&STYLES=";
+					}
 				}
 				
 				String url = geoserver + ""
@@ -116,7 +135,7 @@ public class MapGeneratorUtils {
 //					+ "&FORMAT=image/png"
 //					+ "&TRANSPARENT=true";
 				
-				logger.trace("wms request created: "+url);
+				logger.info("wms request created: "+url);
 				
 				ImageLoaderThread thread = (i==0) ? new ImageLoaderThread(url, opacities[0]) : new ImageLoaderThread(url);
 				executor.execute(thread);
@@ -297,7 +316,7 @@ public class MapGeneratorUtils {
 	}
 	
 	public static void main(String[] args) {
-	    String LINK1 = "http://romeo.jrc.it/maps/mapserv.cgi?map=../mapfiles/acpmap_static.map&LAYERS=truemarble&TRANSPARENT=FALSE&FORMAT=image%2Fpng&SERVICE=WMS&VERSION=1.1.1&REQUEST=GetMap&STYLES=&EXCEPTIONS=application%2Fvnd.ogc.se_inimage&SRS=EPSG%3A4326&BBOX=-180,-90,180,90&WIDTH=1024&HEIGHT=768";
+	    String LINK1 = "http://romeo.jrc.it/maps/mapserv.cgi?map=../mapfiles/acpmap_static.map&LAYERS=truemarble&TRANSPARENT=FALSE&FORMAT=image%2Fpng&SERVICE=WMS&VERSION=1.1.1&REQUEST=GetMap&STYLES=&EXCEPTIONS=application%2Fvnd.ogc.se_inimage&SRS=EPSG%3A4326&BBOX=-180,90,180,-90&WIDTH=1024&HEIGHT=768";
 	    String LINK2 = "http://egip.brgm-rec.fr/wxs/?SERVICE=WMS&version=1.1.0&REQUEST=GetMap&LAYERS=HeatFlowUnit&BBOX=-14.52392578125,37.94677734375,43.70361328125,56.27197265625&WIDTH=1325&HEIGHT=417&SRS=EPSG:4326&FORMAT=image/png";
 	    
 	    BufferedImage img1 = null;
